Merge "[qca-nss-drv] Export bridge verify API and rename function."
diff --git a/exports/nss_bridge.h b/exports/nss_bridge.h
index de25019..fe83147 100644
--- a/exports/nss_bridge.h
+++ b/exports/nss_bridge.h
@@ -83,6 +83,17 @@
 };
 
 /**
+ * nss_bridge_verify_if_num
+ *	Verifies if the interface is type bridge.
+ *
+ * @param[in] if_num  Interface number to be verified.
+ *
+ * @return
+ * True if if_num is of type bridge.
+ */
+bool nss_bridge_verify_if_num(uint32_t if_num);
+
+/**
  * nss_bridge_tx_msg
  *	Sends bridge messages to the NSS.
  *
diff --git a/nss_bridge.c b/nss_bridge.c
index 12bbffa..1e8fda4 100644
--- a/nss_bridge.c
+++ b/nss_bridge.c
@@ -91,23 +91,6 @@
 EXPORT_SYMBOL(nss_bridge_get_context);
 
 /*
- * nss_bridge_verify_if_num()
- *	Verify if_num passed to us.
- */
-static bool nss_bridge_verify_if_num(uint32_t if_num)
-{
-	if (nss_is_dynamic_interface(if_num) == false) {
-		return false;
-	}
-
-	if (nss_dynamic_interface_get_type(nss_bridge_get_context(), if_num) != NSS_DYNAMIC_INTERFACE_TYPE_BRIDGE) {
-		return false;
-	}
-
-	return true;
-}
-
-/*
  * nss_bridge_callback()
  *	Callback to handle the completion of NSS->HLOS messages.
  */
@@ -132,6 +115,24 @@
 }
 
 /*
+ * nss_bridge_verify_if_num()
+ *	Verify if_num passed to us.
+ */
+bool nss_bridge_verify_if_num(uint32_t if_num)
+{
+	if (nss_is_dynamic_interface(if_num) == false) {
+		return false;
+	}
+
+	if (nss_dynamic_interface_get_type(nss_bridge_get_context(), if_num) != NSS_DYNAMIC_INTERFACE_TYPE_BRIDGE) {
+		return false;
+	}
+
+	return true;
+}
+EXPORT_SYMBOL(nss_bridge_verify_if_num);
+
+/*
  * nss_bridge_tx_msg()
  *	Transmit a bridge message to NSSFW
  */
diff --git a/nss_cmn.c b/nss_cmn.c
index 44dc27b..b3661c5 100644
--- a/nss_cmn.c
+++ b/nss_cmn.c
@@ -153,10 +153,10 @@
 }
 
 /*
- * nss_cmn_interface_is_virtual()
- * 	Return true if the interface number is a virtual NSS interface
+ * nss_cmn_interface_is_redirect()
+ * 	Return true if the interface is a redirect interface.
  */
-bool nss_cmn_interface_is_virtual(struct nss_ctx_instance *nss_ctx, int32_t interface_num)
+bool nss_cmn_interface_is_redirect(struct nss_ctx_instance *nss_ctx, int32_t interface_num)
 {
 	return (nss_dynamic_interface_get_type(nss_ctx, interface_num) == NSS_DYNAMIC_INTERFACE_TYPE_WIFI)
 		|| (nss_dynamic_interface_get_type(nss_ctx, interface_num) == NSS_DYNAMIC_INTERFACE_TYPE_802_3_REDIR)
@@ -244,7 +244,7 @@
 EXPORT_SYMBOL(nss_cmn_get_interface_number);
 EXPORT_SYMBOL(nss_cmn_get_interface_dev);
 EXPORT_SYMBOL(nss_cmn_get_state);
-EXPORT_SYMBOL(nss_cmn_interface_is_virtual);
+EXPORT_SYMBOL(nss_cmn_interface_is_redirect);
 EXPORT_SYMBOL(nss_cmn_msg_init);
 EXPORT_SYMBOL(nss_cmn_get_interface_number_by_dev);
 
diff --git a/exports/nss_cmn.h b/exports/nss_cmn.h
index cb078a0..abfddcb 100644
--- a/exports/nss_cmn.h
+++ b/exports/nss_cmn.h
@@ -243,16 +243,16 @@
 extern int32_t nss_cmn_get_interface_number_by_dev(struct net_device *dev);
 
 /**
  * nss_cmn_interface_is_virtual
  *	Determines if the interface number is represented as a virtual interface.
  *
  * @param[in] nss_ctx        Pointer to the NSS context.
  * @param[in] interface_num  NSS interface number.
  *
  * @return
  * TRUE if the number is a virtual interface. Otherwise FALSE.
  */
-extern bool nss_cmn_interface_is_virtual(struct nss_ctx_instance *nss_ctx, int32_t interface_num);
+extern bool nss_cmn_interface_is_redirect(struct nss_ctx_instance *nss_ctx, int32_t interface_num);
 
 /**
  * nss_cmn_get_interface_dev
@@ -243,16 +243,16 @@
 
 /**
- * nss_cmn_interface_is_virtual
- *	Determines if the interface number is represented as a virtual interface.
+ * nss_cmn_interface_is_redirect
+ *	Determines if the interface number is a redirect interface.
  *
  * @param[in] nss_ctx        Pointer to the NSS context.
@@ -243,16 +243,16 @@
  *
  * @return
- * TRUE if the number is a virtual interface. Otherwise FALSE.
+ * TRUE if the number is a redirect interface. Otherwise FALSE.
  */
diff --git a/nss_core.c b/nss_core.c
index f0f8f62..a9997a3 100644
--- a/nss_core.c
+++ b/nss_core.c
@@ -2088,9 +2088,9 @@
 	uint32_t if_num, struct sk_buff *nbuf, int min_skb_size)
 {
 	/*
 	 * Don't re-use if this is a virtual interface.
 	 */
-	if (nss_cmn_interface_is_virtual(nss_ctx, if_num)) {
+	if (nss_cmn_interface_is_redirect(nss_ctx, if_num)) {
 		return false;
 	}
@@ -2088,9 +2088,9 @@
 {
 	/*
-	 * Don't re-use if this is a virtual interface.
+	 * Don't re-use if this is a redirect interface.
 	 */